@@ -102,11 +102,20 @@ class Generator(object):
 
     # ------------------------
     def _remove_empty_tags(self, soup: PageElement):
+
+        def is_blank(el):
+            if len(el.get_text(strip=True)) != 0:
+                return False
+            elif el.find(['img', 'svg']):
+                return False
+            else:
+                return True
+
         includes = ['article', 'p']
         while True:
             hit = False
             for x in soup.find_all():
-                if x.name in includes and len(x.get_text(strip=True)) == 0:
+                if x.name in includes and is_blank(x):
                     # self.logger.debug(f'Strip: {x}')
                     x.extract()
                     hit = True
@@ -127,8 +136,9 @@ class Generator(object):
         if page == parent.children[0]:
             article = self._shift_heading(article, parent, parent.parent)
 
-            id = page.url if not page.url else str(uuid4())
+            id = page.url if (hasattr(page, 'url') and page.url) else ''
             id = id.strip('/').rstrip('/')
+            id = id if id else str(uuid4())
 
             soup = BeautifulSoup('', 'html.parser')
             h1 = soup.new_tag('h1', id=f'{id}')
